YARP 3.1.2 (2019-06-03)                                                {#v3_1_2}
=======================

[TOC]

YARP 3.1.2 Release Notes
========================


A (partial) list of bug fixed and issues resolved in this release can be found
[here](https://github.com/robotology/yarp/issues?q=label%3A%22Fixed+in%3A+YARP+v3.1.2%22).


Bug Fixes
---------

### CMake

* Fixed issue in `YarpPlugin` when INTERNAL is enabled and dependencies are not
  available (#2024).

### Libraries

#### `YARP_dev`

* Fixed `PolyDriver` linking issues on Ubuntu 18.04.


### Devices

#### `realsense2`

* Correctly detect color sensor on D435i (#2010).


Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v3.1.1..v3.1.2`):

```
     9	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
     2	Alberto Cardellino <alberto.cardellino@iit.it>
     1	Bartek Łukawski <bwmn.peter@gmail.com>
     1	Emilio Benenati <emilio.benenati@iit.it>
```
